"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const utils_1 = require("../utils");
exports.default = (options) => {
    return schematics_1.chain([
        addDependencies(options),
        addCommitlintConfigFile(options),
        addDependency(options.husky) ? addHuskyConfig(options) : schematics_1.noop(),
        addDependency(options.commitizen) ? addCommitizenConfig(options) : schematics_1.noop(),
        addDependency(options.standardVersion) ? addNpmRunScript(options) : schematics_1.noop(),
        addDependency(options.standardVersion) && options.issuePrefix
            ? standardVersionConfig(options)
            : schematics_1.noop(),
        options.skipInstall ? schematics_1.noop() : installDependencies,
    ]);
};
const addDependency = (configForDependency) => {
    return configForDependency === true || typeof configForDependency === 'undefined';
};
const addDependencies = (options) => (tree, context) => {
    context.logger.info('Added npm packages as dev dependencies');
    const packageJson = utils_1.getPackageJson(tree);
    let devDepsToAdd = {
        '@commitlint/cli': '^8.2.0',
        '@commitlint/config-conventional': '^8.2.0',
    };
    if (addDependency(options.commitizen)) {
        devDepsToAdd = Object.assign(Object.assign({}, devDepsToAdd), { commitizen: '^4.0.3', 'cz-conventional-changelog': '^3.0.2' });
    }
    else {
        context.logger.info('- Skips adding commitizen');
    }
    if (addDependency(options.husky)) {
        devDepsToAdd = Object.assign(Object.assign({}, devDepsToAdd), { husky: '^3.0.9' });
    }
    else {
        context.logger.info('- Skips adding husky');
    }
    if (addDependency(options.standardVersion)) {
        devDepsToAdd = Object.assign(Object.assign({}, devDepsToAdd), { 'standard-version': '^7.0.0' });
    }
    else {
        context.logger.info('- Skips adding standard-version');
    }
    packageJson.devDependencies = Object.assign(Object.assign({}, packageJson.devDependencies), devDepsToAdd);
    utils_1.overwritePackageJson(tree, packageJson);
};
const addNpmRunScript = (options) => (tree, context) => {
    context.logger.info('Added npm script for release');
    const packageJson = utils_1.getPackageJson(tree);
    const scriptsToAdd = {
        release: 'standard-version',
    };
    if (options.force) {
        packageJson.scripts = Object.assign(Object.assign({}, packageJson.scripts), scriptsToAdd);
    }
    else {
        packageJson.scripts = Object.assign(Object.assign({}, scriptsToAdd), packageJson.scripts);
    }
    utils_1.overwritePackageJson(tree, packageJson);
};
const addHuskyConfig = (options) => (tree, context) => {
    context.logger.info('Added husky configuration');
    const packageJson = utils_1.getPackageJson(tree);
    const huskyConfig = {
        hooks: {
            'commit-msg': 'commitlint -E HUSKY_GIT_PARAMS',
        },
    };
    if (options.force) {
        packageJson.husky = Object.assign(Object.assign({}, packageJson.husky), huskyConfig); // override
    }
    else {
        packageJson.husky = Object.assign(Object.assign({}, huskyConfig), packageJson.husky); // keep existing
    }
    utils_1.overwritePackageJson(tree, packageJson);
};
const addCommitizenConfig = (options) => (tree, context) => {
    context.logger.info('Added commitizen configuration');
    const packageJson = utils_1.getPackageJson(tree);
    const commitizenConfig = {
        commitizen: {
            path: './node_modules/cz-conventional-changelog',
        },
    };
    if (options.force) {
        packageJson.config = Object.assign(Object.assign({}, packageJson.config), commitizenConfig); // override
    }
    else {
        packageJson.config = Object.assign(Object.assign({}, commitizenConfig), packageJson.config); // keep existing
    }
    utils_1.overwritePackageJson(tree, packageJson);
};
const standardVersionConfig = (options) => (tree, context) => {
    context.logger.info('Added standard-version config');
    const packageJson = utils_1.getPackageJson(tree);
    const scriptsToAdd = {
        issuePrefixes: [options.issuePrefix || ''],
    };
    if (options.force) {
        packageJson['standard-version'] = Object.assign(Object.assign({}, packageJson['standard-version']), scriptsToAdd); // override
    }
    else {
        packageJson['standard-version'] = Object.assign(Object.assign({}, scriptsToAdd), packageJson['standard-version']); // keep existing
    }
    utils_1.overwritePackageJson(tree, packageJson);
};
const addCommitlintConfigFile = (options) => (tree, context) => {
    context.logger.info('Added commitlint configuration file');
    const sourceTemplates = schematics_1.url('./files');
    const sourceParameterizedTemplates = schematics_1.apply(sourceTemplates, [
        schematics_1.template({
            issuePrefix: options.issuePrefix || '',
        }),
        schematics_1.forEach((fileEntry) => {
            // override existing files if force flag has been set
            if (options.force && tree.exists(fileEntry.path)) {
                tree.overwrite(fileEntry.path, fileEntry.content);
                return null;
            }
            return fileEntry;
        }),
    ]);
    return schematics_1.mergeWith(sourceParameterizedTemplates)(tree, context);
};
const installDependencies = () => (_tree, context) => {
    context.logger.info('Installs npm dependencies');
    context.addTask(new tasks_1.NodePackageInstallTask());
};
//# sourceMappingURL=index.js.map